// Inspired by
// https://observablehq.com/@d3/parallel-coordinates
// https://observablehq.com/@d3/brushable-parallel-coordinates

import {
  select,
  transition,
  scaleLinear,
  scalePoint,
  scaleOrdinal,
  schemeCategory10,
  extent,
  line,
  brushY,
} from 'd3';
import { data } from '@216vignesh/4a3ee38d057a4c23a012efafcd71c3c5';
import { observeResize } from '@curran/responsive-axes';
import { parallelCoordinates } from './parallelCoordinates';
const myColorScheme = scaleOrdinal(schemeCategory10);
// Assign d.id to the index.
// This is used later for object constancy in transitions.
data.forEach((d, i) => {
  d.id = i;
  const dateParts = d.Start_Date.split('/');
  d.Year = +dateParts[2]; // Assuming the date format is MM/DD/YYYY
  // d.Data_Value = +d.Data_Value; // Convert to float
});

// You might need to decide whether to keep the original 'Name' column or the extracted 'Year'
const columns = ['Data_Value', 'Name', 'Year'];
const columnTypes = {
  Name: 'categorical',
  Data_Value: 'quantitative',
  Year: 'quantitative',
};

// Choose an appropriate color encoding, for example by 'Geo_Place_Name' or 'Year'
const colorValue = (d) => d.Geo_Place_Name;
const idValue = (d) => d.id;

export const main = (container, { state, setState }) => {
  // Initialize dimensions by observing resise.
  const dimensions = observeResize({
    state,
    setState,
    container,
  });
  if (dimensions === null) return;
  const { width, height } = dimensions;

  // Initialize the brushed intervals state to an empty object.
  if (!state.brushedIntervals) {
    setState((state) => ({
      ...state,
      brushedIntervals: {},
    }));
    return;
  }
  const { brushedIntervals } = state;

  // Updates the brushed intervals when brushes change.
  const updateBrushedInterval = ({ column, interval }) => {
    setState((state) => ({
      ...state,
      brushedIntervals: {
        ...state.brushedIntervals,
        [column]: interval,
      },
    }));
  };

  // Use this to inspect the brushedIntervals as they change!
  // console.log(
  //   JSON.stringify(brushedIntervals, null, 2),
  // );

  // Set up the SVG.
  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#9bbfc9');

  // Invoke the parallel coordinates.
  svg.call(parallelCoordinates, {
    data,
    columns,
    columnTypes,
    colorValue,
    idValue,
    width,
    height,
    brushedIntervals,
    updateBrushedInterval,
  });
  // svg.selectAll('.line').style('stroke-opacity', 0.5);
};
